<?xml version="1.0" encoding="UTF-8"?>

<!--
    地方海上警報 全内容出力スタイルシート
    ver1.0.0 2016年09月15日
    ver1.1.0 2019年04月24日  5月1日より施行される新元号への対応
-->

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:jmx="http://xml.kishou.go.jp/jmaxml1/"
    xmlns:h="http://xml.kishou.go.jp/jmaxml1/informationBasis1/"
    xmlns:b="http://xml.kishou.go.jp/jmaxml1/body/meteorology1/"
    xmlns:jmx_eb="http://xml.kishou.go.jp/jmaxml1/elementBasis1/">

    <xsl:output method="html" indent="no" encoding="Shift-JIS"/>

    <!-- メイン -->
    <xsl:template match="/">
        <html>
            <body>
                <xsl:apply-templates select="jmx:Report/jmx:Control"/>
                <xsl:apply-templates select="jmx:Report/h:Head"/>
                <xsl:apply-templates select="jmx:Report/h:Head/h:Headline/h:Information"/>
                <xsl:apply-templates select="jmx:Report/b:Body/b:Warning"/>
                <xsl:apply-templates select="jmx:Report/b:Body/b:MeteorologicalInfos"/>
            </body>
        </html>
    </xsl:template>

    <!-- Control部を出力 -->
    <xsl:template match="jmx:Control">
        <table border="1">
            <tr>
                <th>タイトル</th>
                <th>送信時刻</th>
                <th>通常／訓練／試験</th>
                <th>編集官署</th>
                <th>発表官署</th>
            </tr>
            <tr>
                <td><xsl:value-of select="jmx:Title"/></td>
                <td><xsl:value-of select="jmx:DateTime"/></td>
                <td><xsl:value-of select="jmx:Status"/></td>
                <td><xsl:value-of select="jmx:EditorialOffice"/></td>
                <td><xsl:value-of select="jmx:PublishingOffice"/></td>
            </tr>
        </table>
        <br/>
    </xsl:template>

    <!-- Head部（Headline部を除く）を出力 -->
    <xsl:template match="h:Head">
        <table border="1">
            <tr>
                <th>タイトル</th>
                <th>発表時刻</th>
                <th>基点時刻</th>
                <th>失効時刻</th>
                <th>発表／訂正</th>
            </tr>
            <tr>
                <td><xsl:value-of select="h:Title"/></td>
                <td><xsl:value-of select="h:ReportDateTime"/></td>
                <td><xsl:value-of select="h:TargetDateTime"/></td>
                <td><xsl:value-of select="h:ValidDateTime"/></td>
                <td><xsl:value-of select="h:InfoType"/></td>
            </tr>
        </table>
        <br/>
    </xsl:template>

    <!-- Headline部を出力 -->
    <xsl:template match="h:Information">
        <p><xsl:value-of select="@type"/></p>
        <table border="1">
            <tr>
                <th>海上警報</th>
                <th>海域</th>
            </tr>
            <!-- 海上警報の種類別に出力 -->
            <xsl:apply-templates select="." mode="EachName">
                <xsl:with-param name="name">海上台風警報</xsl:with-param>
            </xsl:apply-templates>
            <xsl:apply-templates select="." mode="EachName">
                <xsl:with-param name="name">海上暴風警報</xsl:with-param>
            </xsl:apply-templates>
            <xsl:apply-templates select="." mode="EachName">
                <xsl:with-param name="name">海上強風警報</xsl:with-param>
            </xsl:apply-templates>
            <xsl:apply-templates select="." mode="EachName">
                <xsl:with-param name="name">海上風警報</xsl:with-param>
            </xsl:apply-templates>
            <xsl:apply-templates select="." mode="EachName">
                <xsl:with-param name="name">海上濃霧警報</xsl:with-param>
            </xsl:apply-templates>
            <xsl:apply-templates select="." mode="EachName">
                <xsl:with-param name="name">海上うねり警報</xsl:with-param>
            </xsl:apply-templates>
            <xsl:apply-templates select="." mode="EachName">
                <xsl:with-param name="name">海上着氷警報</xsl:with-param>
            </xsl:apply-templates>
            <xsl:apply-templates select="." mode="EachName">
                <xsl:with-param name="name">海上警報解除</xsl:with-param>
            </xsl:apply-templates>
        </table>
        <br/>
    </xsl:template>

    <!-- 海上警報の種類別に出力 -->
    <xsl:template match="h:Information" mode="EachName">
        <xsl:param name="name"/>
        <xsl:if test="h:Item[h:Kind/h:Name = $name]">
            <tr>
                <xsl:apply-templates select="(h:Item/h:Kind[h:Name = $name])[1]"/>
                <td><xsl:apply-templates select="h:Item[h:Kind/h:Name = $name]/h:Areas/h:Area"/></td>
            </tr>
        </xsl:if>
    </xsl:template>

    <!-- 警報名とコードを出力 -->
    <xsl:template match="h:Kind">
        <td><xsl:apply-templates select="." mode="NameAndCode"/></td>
    </xsl:template>

    <!-- 海域名とコードを出力（空白で区切る） -->
    <xsl:template match="h:Area">
        <xsl:if test="position() > 1">
            <xsl:text>　</xsl:text>
        </xsl:if>
        <xsl:apply-templates select="." mode="NameAndCode"/>
    </xsl:template>

    <!-- 名称とコードを出力 -->
    <xsl:template match="h:Kind|h:Area" mode="NameAndCode">
        <xsl:value-of select="h:Name"/>
        <xsl:text>（</xsl:text>
        <xsl:value-of select="h:Code"/>
        <xsl:text>）</xsl:text>
    </xsl:template>

    <!-- BodyのWarning部を出力 -->
    <xsl:template match="b:Warning">
        <!-- 海上警報の種類別に出力 -->
        <xsl:apply-templates select="." mode="EachName">
            <xsl:with-param name="name">海上台風警報</xsl:with-param>
        </xsl:apply-templates>
        <xsl:apply-templates select="." mode="EachName">
            <xsl:with-param name="name">海上暴風警報</xsl:with-param>
        </xsl:apply-templates>
        <xsl:apply-templates select="." mode="EachName">
            <xsl:with-param name="name">海上強風警報</xsl:with-param>
        </xsl:apply-templates>
        <xsl:apply-templates select="." mode="EachName">
            <xsl:with-param name="name">海上風警報</xsl:with-param>
        </xsl:apply-templates>
        <xsl:apply-templates select="." mode="EachName">
            <xsl:with-param name="name">海上濃霧警報</xsl:with-param>
        </xsl:apply-templates>
        <xsl:apply-templates select="." mode="EachName">
            <xsl:with-param name="name">海上うねり警報</xsl:with-param>
        </xsl:apply-templates>
        <xsl:apply-templates select="." mode="EachName">
            <xsl:with-param name="name">海上着氷警報</xsl:with-param>
        </xsl:apply-templates>
        <xsl:apply-templates select="." mode="EachName">
            <xsl:with-param name="name">海上警報解除</xsl:with-param>
        </xsl:apply-templates>
    </xsl:template>

    <!-- 海上警報の種類別に出力 -->
    <xsl:template match="b:Warning" mode="EachName">
        <xsl:param name="name"/>
        <xsl:if test="b:Item[b:Kind/b:Name = $name]">
            <xsl:apply-templates select="(b:Item/b:Kind[b:Name = $name])[1]"/>
            <table border="1">
                <tr>
                    <th>海域</th>
                    <th>（特定海域）</th>
                    <th>警報平文</th>
                    <th>予想時間</th>
                    <th colspan="2">量的予想</th>
                    <th>付加事項</th>
                </tr>
                <xsl:choose>
                <xsl:when test="$name = '海上警報解除'">
                    <xsl:apply-templates select="b:Item[b:Kind/b:Name = $name]" mode="Cancel"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="b:Item[b:Kind/b:Name = $name]/b:Kind/b:Property/*/b:SubArea"/>
                </xsl:otherwise>
                </xsl:choose>
            </table>
            <br/>
        </xsl:if>
    </xsl:template>

    <!-- 警報名とコードを出力 -->
    <xsl:template match="b:Kind">
        <p><xsl:apply-templates select="." mode="NameAndCode"/></p>
    </xsl:template>

    <!-- 各海域（特定海域）毎に出力 -->
    <xsl:template match="b:SubArea">
        <tr>
            <xsl:apply-templates select="." mode="Area"/>
            <xsl:apply-templates select="." mode="Sentence"/>
            <xsl:choose>
            <xsl:when test="b:Base">
                <xsl:apply-templates select="b:Base"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="NoBase"/>
            </xsl:otherwise>
            </xsl:choose>
            <xsl:apply-templates select="." mode="Remark"/>
        </tr>
        <xsl:apply-templates select="b:Becoming"/>
    </xsl:template>

    <!-- 海域名とコードを出力 -->
    <!-- 特定海域がある場合は特定海域名も出力 -->
    <xsl:template match="b:SubArea" mode="Area">
        <xsl:choose>
        <xsl:when test="b:AreaName">
            <!-- 特定海域がある場合 -->
            <td>
                <xsl:attribute name="rowspan">
                    <xsl:value-of select="count(b:Becoming) + 1"/>
                </xsl:attribute>
                <xsl:apply-templates select="../../../../b:Area" mode="NameAndCode"/>
            </td>
            <td>
                <xsl:attribute name="rowspan">
                    <xsl:value-of select="count(b:Becoming) + 1"/>
                </xsl:attribute>
                <xsl:value-of select="b:AreaName"/>
            </td>
        </xsl:when>
        <xsl:otherwise>
            <!-- 特定海域がない場合 -->
            <td colspan="2">
                <xsl:attribute name="rowspan">
                    <xsl:value-of select="count(b:Becoming) + 1"/>
                </xsl:attribute>
                <xsl:apply-templates select="../../../../b:Area" mode="NameAndCode"/>
            </td>
        </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- 警報平文を出力 -->
    <xsl:template match="b:SubArea" mode="Sentence">
        <td>
            <xsl:attribute name="rowspan">
                <xsl:value-of select="count(b:Becoming) + 1"/>
            </xsl:attribute>
            <xsl:value-of select="b:Sentence"/>
        </td>
    </xsl:template>

    <!-- 付加事項を出力 -->
    <xsl:template match="b:SubArea" mode="Remark">
        <td>
            <xsl:attribute name="rowspan">
                <xsl:value-of select="count(b:Becoming) + 1"/>
            </xsl:attribute>
            <xsl:value-of select="b:Remark"/>
        </td>
    </xsl:template>

    <!-- 予想(Base)を出力 -->
    <xsl:template match="b:Base">
        <td>今後</td>
        <xsl:apply-templates select="." mode="Common"/>
    </xsl:template>

    <!-- 予想(Base)がない場合用 -->
    <xsl:template name="NoBase">
        <td>今後</td>
        <td colspan="2"></td>
    </xsl:template>

    <!-- 予想(Becoming)を出力 -->
    <xsl:template match="b:Becoming">
        <tr>
            <td><xsl:value-of select="b:TimeModifier"/></td>
            <xsl:apply-templates select="." mode="Common"/>
        </tr>
    </xsl:template>

    <!-- 量的予想を出力 -->
    <xsl:template match="b:Base|b:Becoming" mode="Common">
        <xsl:if test="../../../b:Type = '風'">
            <xsl:apply-templates select="." mode="Wind"/>
        </xsl:if>
        <xsl:if test="../../../b:Type = '濃霧'">
            <xsl:apply-templates select="." mode="Visibility"/>
        </xsl:if>
        <xsl:if test="../../../b:Type = 'うねり'">
            <xsl:apply-templates select="." mode="WaveHeight"/>
        </xsl:if>
        <xsl:if test="../../../b:Type = '着氷'">
            <xsl:apply-templates select="." mode="Icing"/>
        </xsl:if>
    </xsl:template>

    <!-- 量的予想を出力（風用） -->
    <xsl:template match="b:Base|b:Becoming" mode="Wind">
        <td><xsl:apply-templates select="jmx_eb:WindDirection"/></td>
        <td>
            <xsl:apply-templates select="jmx_eb:WindSpeed[not(@unit = 'm/s')]"/>
            <xsl:if test="jmx_eb:WindSpeed[@unit = 'm/s']">
                <xsl:text>（</xsl:text>
                <xsl:apply-templates select="jmx_eb:WindSpeed[@unit = 'm/s']"/>
                <xsl:text>）</xsl:text>
            </xsl:if>
        </td>
    </xsl:template>

    <!-- 量的予想を出力（視程用） -->
    <xsl:template match="b:Base|b:Becoming" mode="Visibility">
        <td colspan="2">
            <xsl:apply-templates select="jmx_eb:Visibility[not(@unit = 'km')]"/>
            <xsl:if test="jmx_eb:Visibility[@unit = 'km']">
                <xsl:text>（</xsl:text>
                <xsl:apply-templates select="jmx_eb:Visibility[@unit = 'km']"/>
                <xsl:text>）</xsl:text>
            </xsl:if>
        </td>
    </xsl:template>

    <!-- 量的予想を出力（波高用） -->
    <xsl:template match="b:Base|b:Becoming" mode="WaveHeight">
        <td colspan="2"><xsl:value-of select="jmx_eb:WaveHeight/@description"/></td>
    </xsl:template>

    <!-- 量的予想を出力（着氷用） -->
    <xsl:template match="b:Base|b:Becoming" mode="Icing">
        <td colspan="2"><xsl:value-of select="jmx_eb:Icing/@description"/></td>
    </xsl:template>

    <!-- 風向を出力 -->
    <xsl:template match="jmx_eb:WindDirection">
        <xsl:if test="position() > 1">
            <xsl:text>又は</xsl:text>
        </xsl:if>
        <xsl:value-of select="."/>
    </xsl:template>

    <!-- 風速／視程を出力 -->
    <xsl:template match="jmx_eb:WindSpeed|jmx_eb:Visibility">
        <xsl:if test="position() > 1">
            <xsl:text>から</xsl:text>
        </xsl:if>
        <xsl:value-of select="@description"/>
    </xsl:template>

    <!-- 警報解除を出力 -->
    <xsl:template match="b:Item" mode="Cancel">
        <tr>
            <td colspan="2"><xsl:apply-templates select="b:Area" mode="NameAndCode"/></td>
            <td></td>
            <td></td>
            <td colspan="2"></td>
            <td></td>
        </tr>
    </xsl:template>

    <!-- BodyのMeteorologicalInfos部（気象要因）を出力 -->
    <xsl:template match="b:MeteorologicalInfos">
        <p><xsl:value-of select="@type"/></p>
        <table border="1">
            <tr>
                <th>観測日時</th>
                <th>海域</th>
                <th>気象要因</th>
            </tr>
            <xsl:apply-templates select="b:MeteorologicalInfo"/>
        </table>
        <br/>
    </xsl:template>

    <!-- BodyのMeteorologicalInfo部（気象要因）を出力 -->
    <xsl:template match="b:MeteorologicalInfo">
        <tr>
            <td><xsl:value-of select="b:Name"/></td>
            <xsl:apply-templates select="b:Item"/>
        </tr>
    </xsl:template>

    <!-- 気象要因を出力 -->
    <xsl:template match="b:Item">
        <xsl:apply-templates select="b:Area"/>
        <td><xsl:value-of select="b:Kind/b:Property/b:SynopsisPart/jmx_eb:Synopsis"/></td>
    </xsl:template>

    <!-- 海域名とコードを出力 -->
    <xsl:template match="b:Area">
        <td><xsl:apply-templates select="." mode="NameAndCode"/></td>
    </xsl:template>

    <!-- 名称とコードを出力 -->
    <xsl:template match="b:Area|b:Kind" mode="NameAndCode">
        <xsl:value-of select="b:Name"/>
        <xsl:text>（</xsl:text>
        <xsl:value-of select="b:Code"/>
        <xsl:text>）</xsl:text>
    </xsl:template>

</xsl:stylesheet>

